*******Full income creation: ELMPS 2012
*******Version 21.0
*******Original 9/3/14
*******Caroline Krafft and Liz Davis
*******Updated 8/6/19 by Caroline Krafft

capture log close

*** Open LOG ***
log using "Full income Egypt data log.log", replace

set more off

****Start with ELMPS 2012 x-section
*use "EG TN Full Income/Data and do files/Original data/elmps 2012 xs v2.3 all.dta", clear
use "Original data/elmps 2012 xs v2.3 all.dta", clear

***Goal: Full income on a monthly basis

*********************************************************
***Monthly wages by types of work****
***Dividing into public, private formal, private informal

*********************************************************

*Start with variables for monthly wage in primary job (mnthwg)
*Secondary job is wgscj3 for 3 months

*Employment status in primary job is usempstp + ussectrp for employment status and sector
*Employment status in secondary job is scempst + and we assume all secondary jobs are informal private jobs
*usformal is formality variable

*Monthly wages secondary job
gen scwgmnth=(wgscj3/(schrswk*13))* schrs3mnth/3 if (usstablp==3 | usstablp==4)
replace scwgmnth=wgscj3/3 if usstablp==1 | usstablp==2

*Monthly wages primary job recalculation for comparability to All Job variable
gen mnthwg2=hrwg*ushrs3mnth/3 if (usstablp==3 | usstablp==4)
replace mnthwg2=mnthwg if usstablp==1 | usstablp==2
replace mnthwg2=mnthwg if wgscj3==. | wgscj3==0

*Public (incl. gov. + public enterprises) wage workers primary job 
gen mnthwg_pub_prim=mnthwg2 if usempstp==1 & ussectrp>=1 & ussectrp<=2

*Private formal wage workers primary job
gen mnthwg_priv_form_prim=mnthwg2 if usempstp==1 & ussectrp>=3 & ussectrp<=6 & usformal==1

*Private informal wage workers primary job
gen mnthwg_priv_inform_prim=mnthwg2 if usempstp==1 & ussectrp>=3 & ussectrp<=6 & usformal==0

*Private informal wage workers sum primary and secondary jobs
egen mnthwg_priv_inform_all=rowtotal(scwgmnth mnthwg_priv_inform_prim)

********************CHECK WAGES BY TYPES: Individual *****************************
egen sumwgtypes_i=rowtotal(mnthwg_pub mnthwg_priv_form mnthwg_priv_inform_all)
gen checkwgtot_i=mnthwgAllJob-sumwgtypes
sum checkwgtot_i

***CHECKED ********************
*browse usstablp usempstp ussectrp usformal mnthwg_pub mnthwg_priv_form mnthwg_priv_inform_prim scwgmnth sumwgtypes mnthwgAllJob checkwgtot_i if (checkwgtot_i < -1 | checkwgtot_i>1 )& checkwgtot_i!=.
***************************************************

*Create household-level variables for wages in different types of work
*HH public sector wages
egen hhmnthwg_pub=sum(mnthwg_pub_prim), by(hhid)

*HH private formal wages
egen hhmnthwg_priv_form=sum(mnthwg_priv_form_prim), by(hhid)

*HH private informal wages (all secondary assumed here)
egen hhmnthwg_priv_inform=sum(mnthwg_priv_inform_all), by(hhid)


*********************************************************
*** Wages summed across sectors
*** Already have wages on a monthly basis for wage workers
*** mnthwgAllJob***
*********************************************************

sum mnthwgAllJob

/**Create household-level wage income for all workers
and for household head vs other workers
*/
egen hhmnthwgAllJob=sum(mnthwgAllJob), by(hhid) 

sum hhmnth*
********************CHECK WAGES BY TYPES *****************************
egen sumwgtypes=rowtotal(hhmnthwg_pub hhmnthwg_priv_form hhmnthwg_priv_inform)
gen checkwgtot=hhmnthwgAllJob-sumwgtypes
sum checkwgtot if pn==1

*Keeping household heads
drop if pn!=1

***************************
***************************
*Households
***************************
***************************


******************
*Rules
******************
*All DK is treated as missing, which ultimately is going to be effectively zero
*Creating as zeros if don't receive that type of income
*Conversion to monthly



*****************************************************
*Household enterprise earnings--repeats over housheold members (Q3) 
*****************************************************

****Reported amount to person/household (Converted to Monthly)

**Multiple (up to four) enterprises
sum q13504_1_30*
*tab1 q13504_2_30*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q13504_1_30* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

sum *q13504_1_30* 

*Creating monthly net earnings based on frequency
foreach num of numlist 1/4 {

gen netearntoHH2_`num'=.
*Daily
replace netearntoHH2_`num'=c_q13504_1_30`num'*365.25/12 if q13504_2_30`num'==1
*Weekly
replace netearntoHH2_`num'=c_q13504_1_30`num'*52.1775/12 if q13504_2_30`num'==2
*Fortnightly
replace netearntoHH2_`num'=c_q13504_1_30`num'*52.1775/2/12 if q13504_2_30`num'==3
*Monthly
replace netearntoHH2_`num'=c_q13504_1_30`num' if q13504_2_30`num'==4
*Quarterly
replace netearntoHH2_`num'=c_q13504_1_30`num'/3 if q13504_2_30`num'==5
*Yearly
replace netearntoHH2_`num'=c_q13504_1_30`num'/12 if q13504_2_30`num'==6

*Check
table q13504_2_30`num', c(mean netearntoHH2_`num')
}



****Summing on the household level
egen netearnHH=rowtotal(netearntoHH2_1 netearntoHH2_2 netearntoHH2_3 netearntoHH2_4)

sum netearnHH
sum netearnHH if netearnHH!=0, detail



*****************************************************
*Agricultural enterprise earnings--repeats over housheold members (Q3) 
*****************************************************

***Rental of equipment -- past 12 months
*tab1 q14307_*

egen hhequiprent=rowtotal(q14307*)

sum hhequiprent

*Monthly
replace hhequiprent=hhequiprent/12

***Harvest of Crops -- past 12 months

sum q14405*
*tab1 q14405*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q14405* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

*Adding across crops
egen harvest=rowtotal(c_q14405*)

*Converting to monthly
replace harvest=harvest/12

*Check
sum harvest
sum harvest if harvest!=0


***Other Ag income -- already monthly
*tab1 q145*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q14502 q14504 q14506 q14508 q14510 {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

*Adding up across types
egen otherag=rowtotal(c_q145*)

*Already monthly

sum otherag
sum otherag if otherag!=0


***Sales of livestock -- Past 12 months
*Rule: 75% of livestock sales is income

sum q14209*

*Creating a "clean" version with zeroes and cleaning out missings. 

foreach var of varlist q14209* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

*Adding up across livestock types
egen livesales=rowtotal(c_q14209*)

*Monthly and 75%
replace livesales=livesales/12*.75

***Total Ag income

gen totalag=hhequiprent+harvest+otherag+livesales

sum totalag

sum totalag if totalag!=0


******************************************************
*Non-labor income--repeats over household members (Q3) 
******************************************************

***Pensions, social assistance, financial and other***
*Already monthly

sum q12302*

/*tab1 q12302*/

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q12302* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

sum *q12302* 

*Sum of pensions and social assistance
egen pensionsocialasst = rowtotal(c_q12302a-c_q12302d)
*NOTE: Add in from "other" sources below to get final pensionsocialasst variable
*Add in to pensions/social assistance from (Q12302i)
replace pensionsocialasst = pensionsocialasst + c_q12302i

sum pensionsocialasst
sum pensionsocialasst if pensionsocialasst !=0

*Normal (contributory pensions)
gen pension = c_q12302a
*Social assistance, including for old age and disabled like Sadat/Mubarak pension
egen socasst = rowtotal(c_q12302b-c_q12302d)
*Add in from other responses, farmers' pension etc.
gen socasst2 = socasst + c_q12302i

sum pension socasst socasst2

drop socasst

*Sum of rent, interest and other-taxi
gen rentother = c_q12302e + c_q12302f + c_q12302j
sum rentother
sum c_q12302e  c_q12302f  c_q12302j

**********************************
*Remittances, child support, etc.
**********************************

*Annual, need to make monthly

sum q12213* q12214*
*tab1 q12213* q12214*

foreach var of varlist q12213* q12214* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

egen remitetc=rowtotal(c_q12213* c_q12214*)
replace remitetc=remitetc/12

*Add in from other sources (Q12302), already monthly
replace remitetc = remitetc + c_q12302g +c_q12302h

sum remitetc
sum remitetc if remitetc!=0



**********DEFINE TRANSFERS *************
gen transfers = pensionsocialasst + remitetc

sum transfers
sum transfers if transfers!=0

***Total other sources of income ***
gen nonlaborincome = transfers + rentother

sum nonlaborincome
sum nonlaborincome if nonlaborincome!=0

********************************
*Total income--before transfers
********************************

gen preinc = hhmnthwgAllJob + netearnHH + totalag + rentother

sum preinc, detail


********************************
*Total income--after transfers
********************************

gen postinc = preinc + transfers

sum postinc, detail


*******************
****Household data
*******************

save "HH Full ELMPS 2012.dta", replace

use "Original data/elmps 2012 xs v2.3 all.dta", clear

merge m:1 hhid using "HH Full ELMPS 2012.dta"

tabu _merge
drop _merge




********************************
*Total income--Household income per capita
********************************

gen pcpreinc=preinc/hhsize
gen pcpostinc=postinc/hhsize

gen pchhwg=hhmnthwgAllJob/hhsize
gen pchhmnthwg_pub=hhmnthwg_pub/hhsize
gen pchhmnthwg_priv_form=hhmnthwg_priv_form/hhsize
gen pchhmnthwg_priv_inform=hhmnthwg_priv_inform/hhsize

gen pcnetearnHH=netearnHH/hhsize

gen pctotalag=totalag/hhsize

gen pcremitetc=remitetc/hhsize

gen pcpension=pension/hhsize

gen pcsocasst2 = socasst2/hhsize

gen pcrentother=rentother/hhsize

gen pctransfers=transfers/hhsize

sum pc* [aw=expan], detail

label variable preinc "Pre-transfer household total monthly income"

label variable pcpreinc "Pre-transfer household total monthly income per capita"

rename hhmnthwgAllJob hhwg

label variable hhwg "Household monthly wage earnings"

label variable pchhwg "Household monthly wage earnings per capita"

label variable pchhmnthwg_pub "Household public wages per capita"
label variable pchhmnthwg_priv_form "Household private formal wages per capita"
label variable pchhmnthwg_priv_inform "Household private informal wages per capita"
label variable  pcnetearnHH  "Household enterprise earnings per capita"
label variable pctotalag "Household agric income per capita"
label variable pcremitetc "Household remittances etc per capita"
label variable pcpension "Household pensions per capita"
label variable pcsocasst2 "Household social assistance per capita"
label variable  pcrentother "Household rent, interest, other per capital"
label variable pctransfers "Household transfers per capita"

*Rename weight variable
rename expan_12 expan

**** Create weights to account for household size ***
gen hh_expan = hhsize * expan

****************
*Dataset
****************

*save "EG TN Full Income/Data and do files/ELMPS 2012 full HH inc.dta", replace
save "ELMPS 2012 full HH inc.dta", replace


*-----------------------------------------------------------------------------*


**************************************
**************************************
*Individuals -- 
*Assign Income to Specific HH Members
**************************************
**************************************

use "Original data/elmps 2012 xs v2.3 all.dta", clear


******************
*Rules
******************
*All DK is treated as missing, which ultimately is going to be effectively zero
*Creating as zeros if don't receive that type of income
*Conversion to monthly


*********************************
***Already have monthly wages for wage workers
*********************************

sum mnthwgAllJob

gen iwg=mnthwgAllJob
replace iwg=0 if iwg==.

label variable iwg "Individual monthly wage income" 


*****************************************************
*Household enterprise earnings--repeats over household members (Q3) 
*****************************************************

****Reported amount to person/household (Converted to Monthly)

*Repeats over enterprises
sum q13504_1_30*
tab1 q13504_2_30*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q13504_1_30* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

sum *q13504_1_30* 

*Converting to monthly
foreach num of numlist 1/4 {

gen netearntoHH2_`num'=0
*Daily
replace netearntoHH2_`num'=c_q13504_1_30`num'*365.25/12 if q13504_2_30`num'==1
*Weekly
replace netearntoHH2_`num'=c_q13504_1_30`num'*52.1775/12 if q13504_2_30`num'==2
*Fortnightly
replace netearntoHH2_`num'=c_q13504_1_30`num'*52.1775/2/12 if q13504_2_30`num'==3
*Monthly
replace netearntoHH2_`num'=c_q13504_1_30`num' if q13504_2_30`num'==4
*Quarterly
replace netearntoHH2_`num'=c_q13504_1_30`num'/3 if q13504_2_30`num'==5
*Yearly
replace netearntoHH2_`num'=c_q13504_1_30`num'/12 if q13504_2_30`num'==6

}


***Share in enterprise is based on hours in enterprise work, predicted wages

**Hours
gen ent_hrs=0
replace ent_hrs=ushrswk1 if usempstp>=2 & usempstp<=4 & usecac1d!=0
replace ent_hrs=schrswk if q5205>=2 & q5205<=5 & scecact>999 & scecact<.

*Identify working on the enterprise
foreach num2 of numlist 1/4 {

gen rank_`num2'=. 

foreach num of numlist 1/6 {
replace rank_`num2'=`num' if q13105_`num'_30`num2'==pn 
}

gen in_ent_`num2'=0
replace in_ent_`num2'=1 if rank_`num2'!=.

}

*Number of enterprises engaged in
gen n_ent=in_ent_1+in_ent_2+in_ent_3+in_ent_4

tabu n_ent

*For those with two enterprises, assume that they divide their time equally
replace ent_hrs=ent_hrs/2 if n_ent==2

sum ent_hrs if ent_hrs!=0

*For those with enterprises but no hours, give mean hours
replace ent_hrs=r(mean) if ent_hrs==0 & (in_ent_1==1 | in_ent_2==1 | in_ent_3==1 | in_ent_4==1)


**Model to derive predicted wages

gen age2=age*age

*Private non-agricultural wage work
reg hrwg i.sex  i.region i.region#i.sex i.educ2 i.sex#i.educ2 c.age c.age2 ///
 i.sex#c.age i.sex#c.age2 if ussectrp>=3 & usecac1d!=0 [aw=expan]

predict phwage if n_ent!=0
sum phwage [aw=expan]

*Mean for few missing
replace phwage=r(mean) if n_ent!=0 & phwage==.

foreach num2 of numlist 1/4 {
*Input as hours and predicted wage
gen i_ent_input_`num2'=ent_hrs*phwage if in_ent_`num2'==1
*HH inputs
egen hh_ent_input_`num2'=sum(i_ent_input_`num2') if in_ent_`num2'==1, by(hhid)
*Share of HH input
gen ient_share_`num2'=0
replace ient_share_`num2'=i_ent_input_`num2'/hh_ent_input_`num2' if in_ent_`num2'==1
*Earnings based on share
gen ient_earn_`num2'=0
replace ient_earn_`num2'=ient_share_`num2'*netearntoHH2_`num2' if in_ent_`num2'==1

}



*Summing over multiple enterprises

gen ient_earn= ient_earn_1+ ient_earn_2+ ient_earn_3 + ient_earn_4

sum ient_earn
sum ient_earn if n_ent!=0, detail



 

*****************************************************
*Agricultural enterprise earnings--repeats over household members (Q3) 
*****************************************************

*Do all households have individuals working in ag. to assign to?

gen in_ag=((usempstp>=2 & usempstp<=4 & usecac1d==0) | (q5205>=2 & q5205<=5 & scecact<999 & scecact<.))
egen hh_in_ag=sum(in_ag), by(hhid)

tabu hh_in_ag

tabu hh_in_ag if q14405_701!=.

*Close. Will assign equally to 15+ individuals in household if zeroes
gen ag_elig=(age>=15)
egen hh_ag_elig=sum(ag_elig), by(hhid)

replace in_ag=1 if hh_in_ag==0 & ag_elig==1
replace hh_in_ag=hh_ag_elig if hh_in_ag==0


*Equal shares based on hours
gen ag_hrs=0
replace ag_hrs=ushrswk2 if usempstp>=2 & usempstp<=4 & usecac1d==0
replace ag_hrs=schrswk if q5205>=2 & q5205<=5 & scecact<999

replace ag_hrs=1 if in_ag==1 & ag_hrs==0

***Rental of equipment
tab1 q14307_*

egen hhequiprent=rowtotal(q14307*)

sum hhequiprent

*Monthly and equally per enterprise member
gen ihhequiprent=0
replace ihhequiprent=hhequiprent/12/hh_in_ag if in_ag==1

sum ihhequiprent
sum ihhequiprent if ihhequiprent!=0

***Harvest of Crops

sum q14405*
tab1 q14405*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q14405* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

egen harvest=rowtotal(c_q14405*)

*Monthly and equally per enterprise member
gen iharvest=0
replace iharvest=harvest/12/hh_in_ag if in_ag==1


sum iharvest
sum iharvest if iharvest!=0


***Other Ag income
tab1 q145*

foreach var of varlist q14502 q14504 q14506 q14508 q14510 {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

egen otherag=rowtotal(c_q145*)
*Already monthly

*Per enterprise member
gen iotherag=0
replace iotherag=otherag*in_ag/hh_in_ag if in_ag==1

sum iotherag
sum iotherag if iotherag!=0

***Sales of livestock
*Rule: 75% of livestock sales is income

sum q14209*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q14209* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}


egen livesales=rowtotal(c_q14209*)

*Monthly 75% per 
gen ilivesales=0
replace ilivesales=livesales/12*.75*in_ag/hh_in_ag if in_ag==1

sum ilivesales 
sum ilivesales if ilivesales!=0

***Total Individual Ag income

gen itotalag=ihhequiprent+iharvest+iotherag+ilivesales

sum itotalag

sum itotalag if itotalag!=0


******************************************************
*Non-labor income--repeats over household members (Q3) 
******************************************************

*Assigned to household head
***Pensions, social assistance, financial and other***
*Already monthly

sum q12302*
*Note that this set of questions (q12302 includes rent, interest as well as pensions)
*tab1 q12302*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q12302* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

sum *q12302* 

*Sum of pensions and social assistance (assign to hh head)
egen ipensionsocialasst = rowtotal(c_q12302a-c_q12302d) if reltohd==1
replace ipensionsocialasst=0 if ipensionsocialasst==.

*Add in to pensions/social assistance from (Q12302i), assign to head
replace ipensionsocialasst = ipensionsocialasst + c_q12302i if reltohd==1

sum ipensionsocialasst
sum ipensionsocialasst if ipensionsocialasst !=0

*Normal (contributory pensions)
gen ipension = c_q12302a if reltohd==1
*Social assistance, including for old age and disabled like Sadat/Mubarak pension
egen isocasst = rowtotal(c_q12302b-c_q12302d) if reltohd==1
*Add in from other responses, farmers' pension etc.
gen isocasst2 = isocasst + c_q12302i if reltohd==1 

replace ipension=0 if ipension==.
replace isocasst=0 if isocasst==.
replace isocasst2=0 if isocasst2==.


sum ipension isocasst isocasst2

drop isocasst

*Sum of rent, interest and other-taxi
gen irentother = c_q12302e + c_q12302f + c_q12302j if reltohd==1
replace irentother=0 if irentother==.

sum irentother


**********************************
*Remittances, child support, etc.
**********************************

*Assigned to anyone in particular?

tab1 q12210*

*Usually. Otherwise will assign to adults 15+ 

foreach num of numlist 1/5 {
gen rec_`num'=0
replace rec_`num'=1 if q12211_20`num'==pn
replace rec_`num'=1 if q12210_20`num'==2 & age>=15

egen hh_rec_`num'=sum(rec_`num'), by(hhid)
}


*Annual, need to make monthly

sum q12213* q12214*
*tab1 q12213* q12214*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist q12213* q12214* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.
}

foreach num of numlist 1/5 {
gen i_c_q12213_20`num'=rec_`num'/hh_rec_`num'*c_q12213_20`num'
gen i_c_q12214_20`num'=rec_`num'/hh_rec_`num'*c_q12214_20`num'
}

*Adding types
egen iremitetc=rowtotal(i_c_q12213* i_c_q12214*)

*Monthly
replace iremitetc=iremitetc/12

*Add in from other sources (Q12302), already monthly, assign to head
replace iremitetc = iremitetc + c_q12302g +c_q12302h if reltohd==1

sum iremitetc
sum iremitetc if iremitetc!=0, detail



**********DEFINE TRANSFERS *************
gen itransfers = ipensionsocialasst + iremitetc

sum itransfers
sum itransfers if itransfers!=0

***Total other sources of income ***
gen inonlaborincome = itransfers + irentother

sum inonlaborincome
sum inonlaborincome if inonlaborincome!=0

********************************
*Total income--before transfers
********************************

gen ipreinc=iwg + ient_earn + itotalag + irentother

sum ipreinc, detail

********************************
*Total income--after transfers
********************************

gen ipostinc= ipreinc+itransfers

sum ipostinc, detail

label variable ipreinc "Pre-transfer individual total monthly income"

label variable ipostinc "Post-transfer individual total monthly income"



****************
*Dataset
****************

*save "EG TN Full Income/Data and do files/ELMPS 2012 full indiv inc.dta", replace
save "ELMPS 2012 full indiv inc.dta", replace

*use "EG TN Full Income/Data and do files/ELMPS 2012 full HH inc.dta", clear
use "ELMPS 2012 full HH inc.dta", clear

*merge 1:1 indid using "EG TN Full Income/Data and do files/ELMPS 2012 full indiv inc.dta"
merge 1:1 indid using "ELMPS 2012 full indiv inc.dta"

tabu _merge
drop _merge


***PPP terms
**Rename PPP variables

foreach var of varlist hhwg preinc pcpreinc postinc pcpostinc pchhwg iwg ipreinc {
gen pp_`var'=`var'/3.51
}

*save "EG TN Full Income/Data and do files/ELMPS 2012 full inc.dta", replace
save "ELMPS 2012 full inc.dta", replace

****************
*Checks
****************

*Wages 

table sex [fw=round(expan)], c(sum iwg) format(%15.0f) row col 

table sex [fw=round(expan)] if reltohd==1, c(sum hhwg) format(%15.0f) row col 

*Pre-transfer

table sex [fw=round(expan)], c(sum ipreinc sum pcpreinc) format(%15.0f) row col 

table sex [fw=round(expan)] if reltohd==1, c(sum preinc) format(%15.0f) row col 

*Post-transfer

table sex [fw=round(expan)], c(sum ipreinc sum pcpreinc) format(%15.0f) row col 

table sex [fw=round(expan)] if reltohd==1, c(sum preinc) format(%15.0f) row col  


* Check that individual add up to household

egen total_preinc=sum(ipreinc), by(hhid)
egen total_postinc=sum(ipostinc), by(hhid)
egen total_wages=sum(iwg), by(hhid)
egen total_aginc=sum(itotalag), by(hhid)
egen total_transfers=sum(itransfers), by(hhid)
egen total_remit=sum(iremitetc), by(hhid)

gen check_preinc = preinc-total_preinc
gen check_postinc = postinc-total_postinc
gen check_wages = hhwg-total_wages
gen check_transfers = transfers-total_transfers

sum preinc total_preinc postinc total_postinc hhwg total_wages totalag total_aginc transfers total_transfers remitetc total_remit

sum check*

drop check*
drop total_preinc total_postinc total_wages total_aginc total_transfers  total_remit



**Shorten some variable names
rename pensionsocialasst pensocasst
rename ipensionsocialasst ipensocasst
rename nonlaborincome nonlaborinc
rename inonlaborincome inonlaborinc

***** DATA SET **********
save "ELMPS 2012 full inc.dta", replace
