*******Full income creation: TLMPS 2014
*******Version 24.0
*******Original 12/16/14
*******Updated 8/7/19 by Caroline Krafft

capture log close

*** Open LOG ***
log using "Full income Tunisia data log.log", replace

set more off

****Start with TLMPS 2014 x-section -- use version 2.1

*use "EG TN Full Income/Data and do files/Original data/TLMPS 2014 v2.1 all.dta", clear
use "Original data/TLMPS 2014 v2.1 all.dta", clear

tab1 usempstp ussectrp usstablp

*****************************************
***Goal: Full income on a monthly basis
*****************************************

*********************************************************
***Monthly wages by types of work****
***Dividing into public, private formal, private informal

*********************************************************

*Start with variables for monthly wage in primary job (mnthwg)
*Secondary job is wgscj3 for 3 months

*Employment status in primary job is usempstp + ussectrp for employment status and sector
*Employment status in secondary job is scempst + and we assume all secondary jobs are informal private jobs
*usformal is formality variable

*Monthly wages secondary job
gen scwgmnth=(wgscj3/(schrswk*13))* schrs3mnth/3 if (usstablp==3 | usstablp==4)
replace scwgmnth=wgscj3/3 if usstablp==1 | usstablp==2

*Monthly wages primary job recalculation for comparability to All Job variable
gen mnthwg2=hrwg*ushrs3mnth/3 if (usstablp==3 | usstablp==4)
replace mnthwg2=mnthwg if usstablp==1 | usstablp==2
replace mnthwg2=mnthwg if wgscj3==. | wgscj3==0

*Public (incl. gov. + public enterprises) wage workers primary job 
gen mnthwg_pub_prim=mnthwg2 if usempstp==1 & ussectrp>=1 & ussectrp<=2

*Private formal wage workers primary job
gen mnthwg_priv_form_prim=mnthwg2 if usempstp==1 & ussectrp>=3 & ussectrp<=6 & usformal==1

*Private informal wage workers primary job
gen mnthwg_priv_inform_prim=mnthwg2 if usempstp==1 & ussectrp>=3 & ussectrp<=6 & usformal==0


** Deal with missing informality and / or sector
replace mnthwg_priv_inform_prim=mnthwg2 if usempstp==1 & ((usformal==. | ussectrp==.) & mnthwg_pub_prim==.)

*Private informal wage workers sum primary and secondary jobs
egen mnthwg_priv_inform_all=rowtotal(scwgmnth mnthwg_priv_inform_prim)


********************CHECK WAGES BY TYPES: Individual *****************************
egen sumwgtypes_i=rowtotal(mnthwg_pub mnthwg_priv_form mnthwg_priv_inform_all)
gen checkwgtot_i=mnthwgAllJob-sumwgtypes
sum checkwgtot_i

***CHECKED ********************
*browse usstablp usempstp ussectrp usformal uscont* ussocins mnthwg_pub mnthwg_priv_form mnthwg_priv_inform_prim scwgmnth sumwgtypes mnthwgAllJob checkwgtot_i if (checkwgtot_i < -1 | checkwgtot_i>1 )& checkwgtot_i!=.
***************************************************

*Create household-level variables for wages in different types of work
*HH public sector wages
egen hhmnthwg_pub=sum(mnthwg_pub_prim), by(hhid)

*HH private formal wages
egen hhmnthwg_priv_form=sum(mnthwg_priv_form_prim), by(hhid)

*HH private informal wages (all secondary assumed here)
egen hhmnthwg_priv_inform=sum(mnthwg_priv_inform_all), by(hhid)


*********************************************************
***Already have wages on a monthly basis for wage workers
*** mnthwgAllJob
*********************************************************

sum mnthwgAllJob

egen hhmnthwgAllJob=sum(mnthwgAllJob), by(hhid)
 
*****MISSING WAGE INFO **************
*Missing wages for a wage worker -- create a variable for missing wages (household)
*if household has a wage worker but no wage income
gen misswage=((usempstp==1 | v677==1) & mnthwgAllJob==.) | stat_adult_quest==3
egen hhmisswage=max(misswage), by(hhid)

replace hhmnthwgAllJob=. if hhmisswage==1 
replace hhmnthwg_pub = . if hhmisswage==1
replace hhmnthwg_priv_form = . if hhmisswage==1
replace hhmnthwg_priv_inform = . if hhmisswage==1
******************************************************

/**Create household-level wage income for all workers
and for household head vs other workers
*/

gen hhmnthwgAllJobHHead=mnthwgAllJob if pn==1 
sum hhmnthwgAllJobHHead
replace hhmnthwgAllJobHHead = 0 if hhmnthwgAllJobHHead ==.
sum hhmnthwgAllJobHHead

gen hhmnthwgAllJobNonHead=hhmnthwgAllJob-hhmnthwgAllJobHHead
sum hhmnthwgAllJobNonHead
replace hhmnthwgAllJobNonHead = 0 if hhmnthwgAllJobNonHead ==. //Not needed because none are missing
sum hhmnthwgAllJobNonHead

sum hhmnth*
********************CHECK WAGES BY TYPES *****************************
egen sumwgtypes=rowtotal(hhmnthwg_pub hhmnthwg_priv_form hhmnthwg_priv_inform)
gen checkwgtot=hhmnthwgAllJob-sumwgtypes
sum checkwgtot if pn==1

***************************
***************************
*Households
***************************
***************************
*Keeping household heads
drop if pn!=1

******************
*Rules
******************
*All DK is treated as missing, which ultimately is going to be effectively zero
*Creating as zeros if don't receive that type of income
*Conversion to monthly

*****************************************************
*Household enterprise earnings--repeats over housheold members (Q3) 
*****************************************************

****Reported amount to person/household (Converted to Monthly)

sum m336_1_*
*tab1 m336_2_*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m336_1_* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

sum *m336_1_* 

*Converting to monthly
foreach num of numlist 31/32 {

*No enterprise
gen netearntoHH2_`num'=0 if m301==2 | m302<`num'-30
*Daily
replace netearntoHH2_`num'=c_m336_1_`num'*365.25/12 if m336_2_`num'==1
*Weekly
replace netearntoHH2_`num'=c_m336_1_`num'*52.1775/12 if m336_2_`num'==2
*Fortnightly
replace netearntoHH2_`num'=c_m336_1_`num'*52.1775/2/12 if m336_2_`num'==3
*Monthly
replace netearntoHH2_`num'=c_m336_1_`num' if m336_2_`num'==4
*Quarterly
replace netearntoHH2_`num'=c_m336_1_`num'/6 if m336_2_`num'==5
*Yearly
replace netearntoHH2_`num'=c_m336_1_`num'/12 if m336_2_`num'==6

*Check
table m336_2_`num', c(mean netearntoHH2_`num')

**Set to zero if shouldn't have answered and did 
replace netearntoHH2_`num'=0 if netearntoHH2_`num'!=0 & netearntoHH2_`num'!=. & (m301!=1 | m302<`num'-30)
**Set to missing if should have answered and didn't
replace netearntoHH2_`num'=. if netearntoHH2_`num'==0 & (m301==1 & m302>=`num'-30 & m302!=.)

sum netearntoHH2_`num'

}


****Summing method 2 on the household level
egen netearnHH=rowtotal(netearntoHH2_31 netearntoHH2_32), missing
replace netearnHH=. if netearntoHH2_31==. | netearntoHH2_32==.

sum netearnHH
sum netearnHH if netearnHH!=0, detail



*****************************************************
*Agricultural enterprise earnings--repeats over housheold members (Q3) 
*****************************************************

***Rental of equipment (exception: zero if answered q'are)
tab1 m434_*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach num of numlist 61/75 {
*Answered q'are
gen c_m434_`num'=0 if stat_migr_quest==3

*Rental of item with amount
replace c_m434_`num'=m434_`num' if m433_`num'==1 & m429_`num'==1 & m434_`num'!=. & m434_`num'!=0
}

egen hhequiprent=rowtotal(c_m434*), missing

foreach num of numlist 61/75 {
replace hhequiprent=. if stat_migr_quest!=3
}

sum hhequiprent

*Monthly
replace hhequiprent=hhequiprent/12

***Harvest of Crops

sum m440*
tab1 m440*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m440* {
gen c_`var'=0 if m435==2
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

foreach num of numlist 81/86 {

**Set to zero if don't have that crop
replace c_m440_`num'=0 if (m435==1 & m437_`num'==.)
**Set to zero if shouldn't have answered and did 
replace c_m440_`num'=0 if c_m440_`num'!=0 & c_m440_`num'!=.  & (m435!=1 | m437_`num'==.)
**Set to missing if should have answered and didn't
replace c_m440_`num'=. if c_m440_`num'==0 & (m435==1 & m437_`num'!=.)

sum c_m440_`num'


}

egen harvest=rowtotal(c_m440*), missing

foreach num of numlist 81/86 {
replace harvest=. if c_m440_`num'==.
}

*Monthly
replace harvest=harvest/12

sum harvest
sum harvest if harvest!=0


***Other Ag income
tab1 m442 m444 m446 m448 m450 m452

foreach var of varlist m442 m444 m446 m448 m450 m452 {
gen c_`var'=.
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

*Replace missing if should be non-zero
replace c_m442=. if m441==1 & m442==0

*Replace zero if no income
replace c_m442=0 if m441==2

*Replace missing if should be non-zero
replace c_m444=. if m443==1 & m444==0

*Replace zero if no income
replace c_m444=0 if m443==2

*Replace missing if should be non-zero
replace c_m446=. if m445==1 & m446==0

*Replace zero if no income
replace c_m446=0 if m445==2

*Replace missing if should be non-zero
replace c_m448=. if m447==1 & m448==0

*Replace zero if no income
replace c_m448=0 if m447==2

*Replace missing if should be non-zero
replace c_m450=. if m449==1 & m450==0

*Replace zero if no income
replace c_m450=0 if m449==2

*Replace missing if should be non-zero
replace c_m452=. if m451==1 & m452==0

*Replace zero if no income
replace c_m452=0 if m451==2



egen otherag=rowtotal(c_m442 c_m444 c_m446 c_m448 c_m450 c_m452), missing 

*Already monthly
sum otherag
sum otherag if otherag!=0



***Sales of livestock
*Rule: 75% of livestock sales is income

sum m427*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m427* {
gen c_`var'=.
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}


foreach num of numlist 51/58 {

**Set to zero if don't have or sell that animal
replace c_m427_`num'=0 if (m419==2 | m422_`num'==2 | m425_`num'==2)
**Set to zero if shouldn't have answered and did 
replace c_m427_`num'=0 if c_m427_`num'!=0 & c_m427_`num'!=.  & (m419==2 | m422_`num'==2 | m425_`num'==2)
**Set to missing if should have answered and didn't
replace c_m427_`num'=. if c_m427_`num'==0 & (m419==1 & m422_`num'==1 & m425_`num'==1)

sum c_m427_`num'


}

egen livesales=rowtotal(c_m427*), missing

foreach num of numlist 51/58 {
replace livesales=. if c_m427_`num'==. 
}


*Monthly 75%
replace livesales=livesales/12*.75

sum livesales
sum livesales if livesales!=0

***Total Ag income

gen totalag=hhequiprent+harvest+otherag+livesales

sum totalag

sum totalag if totalag!=0


******************************************************
*Non-labor income--repeats over housheold members (Q3) 
******************************************************

*** Pensions, social assistance, financial and other ***
*Already monthly

sum m249*

tab1 m249*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m249* {
gen c_`var'=.
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

foreach num of numlist 1/7 {
*Missing if not answered y/n
replace c_m249_`num'=. if m248_`num'==.
*Zero if no
replace c_m249_`num'=0 if m248_`num'==2
*Missing if yes and no value
replace c_m249_`num'=. if m248_`num'==1 & c_m249_`num'==0
}

*Fix implausibly large pensions with highest wage observed
replace c_m249_1=9015 if c_m249_1!=. & c_m249_1>9015

sum *m249* 

*Sum of pensions and social assistance

egen pensionsocialasst = rowtotal(c_m249_1-c_m249_4 c_m249_7), missing
foreach num of numlist 1/4 7 {
replace pensionsocialasst=. if c_m249_`num'==.
}

sum pensionsocialasst

*Sum of rent and interest
gen rentother=c_m249_5 + c_m249_6
sum rentother

**********************************
*Remittances, child support, etc.
**********************************

*Annual

sum m246* m247*
tab1 m246* m247*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m246* m247* {
*Zero if receive none
gen c_`var'=0 if m234==2
replace c_`var'=`var'/12 if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=999999 & `var'!=.

}

foreach num of numlist 21/25 {


**Set to zero if don't have that donor
replace c_m246_`num'=0 if m235<`num'-20

**Set to missing if should have answered and didn't
replace c_m246_`num'=. if c_m247_`num'==0 & c_m246_`num'==0 & m235>=`num'-20 & m234==1

sum c_m246_`num'


**Set to zero if don't have that donor
replace c_m247_`num'=0 if m235<`num'-20

**Set to missing if should have answered and didn't
replace c_m247_`num'=. if c_m247_`num'==0 & c_m246_`num'==0 & m235>=`num'-20 & m234==1

sum c_m247_`num'


}


egen remitetc=rowtotal(c_m246* c_m247*), missing

foreach num of numlist 21/25 {
replace remitetc=. if c_m247_`num'==. | c_m246_`num'==.
}


sum remitetc
sum remitetc if remitetc!=0



** Alternative categories of pensions and social assistance
*Normal (contributory pensions)
gen pension = c_m249_1
replace pension=0 if m248_1==2
replace pension=. if m248_1==1 & c_m249_1==0

*Fix implausibly large pensions with highest wage observed
replace c_m249_1=9015 if c_m249_1!=. & c_m249_1>9015

*Social assistance, including for old age and disabled 
egen socasst = rowtotal(c_m249_2 c_m249_3 c_m249_4 c_m249_7), missing
foreach num of numlist 2 3 4 7 {
replace socasst=. if c_m249_`num'==.
*Missing if yes and no value
replace c_m249_`num'=. if m248_`num'==1 & c_m249_`num'==0
}

rename socasst socasst2

sum pension socasst socasst2



gen checknewpen = pensionsocialasst - (pension+socasst2)
 sum checknewpen

**************DEFINE TRANSFERS********************

gen transfers = pensionsocialasst + remitetc

sum transfers
sum transfers if transfers!=0

********** Total nonlabor sources of income ***********
gen nonlaborincome = transfers + rentother

sum nonlaborincome
sum nonlaborincome if nonlaborincome!=0


********************************
*Total income--before transfers
********************************

gen preinc= hhmnthwgAllJob+netearnHH+totalag+rentother

sum preinc, detail
sum preinc if preinc!=0, detail

********************************
*Total income--after transfers
********************************

gen postinc= preinc + transfers

sum postinc, detail
sum postinc if postinc!=0, detail

*******************
****Household data
*******************

save "HH Full TLMPS 2014.dta", replace

use "Original data/TLMPS 2014 v2.1 all.dta", clear

merge m:1 hhid using "HH Full TLMPS 2014.dta"

tabu _merge
drop _merge

drop c_*
drop netearntoHH2_31 netearntoHH2_32 misswage hhmisswage

sum hhmnthwgAllJob netearnHH hhequiprent harvest otherag livesales totalag pensionsocialasst ///
pension socasst2 rentother remitetc transfers nonlaborincome preinc postinc

sum hhmnthwgAllJob netearnHH hhequiprent harvest otherag livesales totalag pensionsocialasst ///
pension socasst2 rentother remitetc transfers nonlaborincome preinc postinc if pn==1


********************************
*Total income--Household income per capita
********************************

gen pcpreinc=preinc/hhsize
gen pcpostinc=postinc/hhsize

gen pchhwg=hhmnthwgAllJob/hhsize
gen pchhmnthwg_pub=hhmnthwg_pub/hhsize
gen pchhmnthwg_priv_form=hhmnthwg_priv_form/hhsize
gen pchhmnthwg_priv_inform=hhmnthwg_priv_inform/hhsize

gen pcnetearnHH=netearnHH/hhsize

gen pctotalag=totalag/hhsize

gen pcremitetc=remitetc/hhsize

gen pcpension=pension/hhsize

gen pcsocasst2 = socasst2/hhsize

gen pcrentother=rentother/hhsize

gen pctransfers=transfers/hhsize

sum pc* [aw=expan_hh], detail
sum pc* [aw=expan_hh]

label variable preinc "Pre-transfer household total monthly income"

label variable pcpreinc "Pre-transfer household total monthly income per capita"

rename hhmnthwgAllJob hhwg


label variable hhwg "Household monthly wage earnings"

label variable pchhwg "Household monthly wage earnings per capita"

label variable pchhmnthwg_pub "Household public wages per capita"
label variable pchhmnthwg_priv_form "Household private formal wages per capita"
label variable pchhmnthwg_priv_inform "Household private informal wages per capita"
label variable  pcnetearnHH  "Household enterprise earnings per capita"
label variable pctotalag "Household agric income per capita"
label variable pcremitetc "Household remittances etc per capita"
label variable pcpension "Household pensions per capita"
label variable pcsocasst2 "Household social assistance per capita"
label variable  pcrentother "Household rent, interest, other per capital"
label variable pctransfers "Household transfers per capita"

*Rename weight variable
gen expan=expan_hh

**** Create weights to account for household size ***
gen hh_expan = hhsize * expan

****************
*Dataset
****************

save "TLMPS 2014 full HH inc.dta", replace


sum hhwg netearnHH hhequiprent harvest otherag livesales totalag pensionsocialasst ///
pension socasst2 rentother remitetc nonlaborincome transfers preinc postinc
sum hhwg netearnHH hhequiprent harvest otherag livesales totalag pensionsocialasst ///
pension socasst2 rentother remitetc nonlaborincome transfers preinc postinc if pn==1


*-----------------------------------------------------------------------------*


***************************
***************************
*Individuals
***************************
***************************

*use "EG TN Full Income/Data and do files/Original data/TLMPS 2014 v2.1 all.dta", clear
use "Original data/TLMPS 2014 v2.1 all.dta", clear

******************
*Rules
******************
*All DK is treated as missing, which ultimately is going to be effectively zero
*Creating as zeros if don't receive that type of income
*Conversion to monthly


*********************************
***Already have monthly wages for wage workers
*********************************

sum mnthwgAllJob

gen iwg=mnthwgAllJob
replace iwg=0 if iwg==. 
replace iwg=. if ((usempstp==1 | v677==1) & mnthwgAllJob==.) | stat_adult_quest==3

label variable iwg "Individual monthly wage income" 


*****************************************************
*Household enterprise earnings--repeats over housheold members (Q3) 
*****************************************************

****Reported amount to person/household (Converted to Monthly)

sum m336_1_*
*tab1 m336_2_*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m336_1_* {
gen c_`var'=0
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

sum *m336_1_* 

*Monthly
foreach num of numlist 31/32 {

*No enterprise
gen netearntoHH2_`num'=0 if m301==2 | m302<`num'-30
*Daily
replace netearntoHH2_`num'=c_m336_1_`num'*365.25/12 if m336_2_`num'==1
*Weekly
replace netearntoHH2_`num'=c_m336_1_`num'*52.1775/12 if m336_2_`num'==2
*Fortnightly
replace netearntoHH2_`num'=c_m336_1_`num'*52.1775/2/12 if m336_2_`num'==3
*Monthly
replace netearntoHH2_`num'=c_m336_1_`num' if m336_2_`num'==4
*Quarterly
replace netearntoHH2_`num'=c_m336_1_`num'/6 if m336_2_`num'==5
*Yearly
replace netearntoHH2_`num'=c_m336_1_`num'/12 if m336_2_`num'==6

*Check
table m336_2_`num', c(mean netearntoHH2_`num')

**Set to zero if shouldn't have answered and did 
replace netearntoHH2_`num'=0 if netearntoHH2_`num'!=0 & netearntoHH2_`num'!=. & (m301!=1 | m302<`num'-30)
**Set to missing if should have answered and didn't
replace netearntoHH2_`num'=. if netearntoHH2_`num'==0 & (m301==1 & m302>=`num'-30 & m302!=.)

sum netearntoHH2_`num'

}


***Share in enterprise is based on hours in enterprise work, predicted wages

**Hours
gen ent_hrs=0
replace ent_hrs=ushrswk1 if usempstp>=2 & usempstp<=4
replace ent_hrs=schrswk if v677>=2 & v677<=5

*Identify working on the enterprise
foreach num2 of numlist 31/32 {

gen rank_`num2'=. 

foreach num of numlist 1/6 {
replace rank_`num2'=`num' if m305_`num'_`num2'==pn 
}

gen in_ent_`num2'=0
replace in_ent_`num2'=1 if rank_`num2'!=.

}

***Fix problem with unassigned enterprise workers
replace in_ent_31 =1 if hhid =="00720101" & pn==1
replace in_ent_31 =1 if hhid=="00720101" & pn==2

*Number of enterprises
gen n_ent=in_ent_31+in_ent_32

tabu n_ent

*For those with two enterprises, assume that they divide their time equally
replace ent_hrs=ent_hrs/2 if n_ent==2

sum ent_hrs if ent_hrs!=0

*For those with enterprises but no hours, give mean hours
replace ent_hrs=r(mean) if ent_hrs==0 & (in_ent_31==1 | in_ent_32==1)
*For those with enterprises but missing hours, give mean hours
replace ent_hrs=r(mean) if ent_hrs==. & (in_ent_31==1 | in_ent_32==1)

**Model for predicted wages

gen age2=age*age

gen lhrwg=ln(hrwg)

*Private non-agricultural wage work
reg lhrwg i.sex  i.region i.region#i.sex i.educlvl2 i.sex#i.educlvl2 c.age c.age2 ///
 i.sex#c.age i.sex#c.age2 if ussectrp>=3  & usecac1d!=0  & usecac1d!=0 [aw=expan_indiv]

predict phwage if n_ent!=0
replace phwage=exp(phwage)
sum phwage [aw=expan_indiv]
*Mean for few missing
replace phwage=r(mean) if n_ent!=0 & phwage==.



foreach num2 of numlist 31/32 {
*Input as hours and predicted wage
gen i_ent_input_`num2'=ent_hrs*phwage if in_ent_`num2'==1
*HH inputs
egen hh_ent_input_`num2'=sum(i_ent_input_`num2') if in_ent_`num2'==1, by(hhid)
*Share of HH input
gen ient_share_`num2'=0
replace ient_share_`num2'=i_ent_input_`num2'/hh_ent_input_`num2' if in_ent_`num2'==1
*Earnings based on share
gen ient_earn_`num2'=0 if netearntoHH2_`num2'!=. 
replace ient_earn_`num2'=ient_share_`num2'*netearntoHH2_`num2' if in_ent_`num2'==1

}



*Summing over multiple enterprises

gen ient_earn= ient_earn_31+ ient_earn_32

****Fix missing data problem (no workers assigned to enterprise)
replace ient_earn = 304.375/2 if hhid=="00660381"

sum ient_earn
sum ient_earn if n_ent!=0, detail


 

*****************************************************
*Agricultural enterprise earnings--repeats over housheold members (Q3) 
*****************************************************

*Do all households have individuals working in ag. to assign to?

gen in_ag=((usempstp>=2 & usempstp<=4 & usecac1d==0 ) | (v677>=2 & v677<=5 & v676<999 & v676<. ))
egen hh_in_ag=sum(in_ag), by(hhid)

tabu hh_in_ag

tabu hh_in_ag if m440_81!=. & m440_81!=0

*Close. Will assign equally to 15+ individuals in household if zeroes
gen ag_elig=(age>=15)
egen hh_ag_elig=sum(ag_elig), by(hhid)

replace in_ag=1 if hh_in_ag==0 & ag_elig==1
replace hh_in_ag=hh_ag_elig if hh_in_ag==0


*Equal shares based on hours
gen ag_hrs=0
replace ag_hrs=ushrswk2 if usempstp>=2 & usempstp<=4 & usecac1d==0
replace ag_hrs=schrswk if v677>=2 & v677<=5 & v676<999

replace ag_hrs=1 if in_ag==1 & ag_hrs==0


***Rental of equipment (exception: zero if answered q'are)
tab1 m434_*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach num of numlist 61/75 {
*Answered q'are
gen c_m434_`num'=0 if stat_migr_quest==3

*Rental of item with amount
replace c_m434_`num'=m434_`num' if m433_`num'==1 & m429_`num'==1 & m434_`num'!=. & m434_`num'!=0
}

egen hhequiprent=rowtotal(c_m434*), missing

foreach num of numlist 61/75 {
replace hhequiprent=. if stat_migr_quest!=3
}

sum hhequiprent

*Monthly and equally per enterprise member
gen ihhequiprent=0 if hhequiprent!=.
replace ihhequiprent=hhequiprent/12/hh_in_ag if in_ag==1

sum ihhequiprent
sum ihhequiprent if ihhequiprent!=0



***Harvest of Crops

sum m440*
tab1 m440*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m440* {
gen c_`var'=0 if m435==2
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

foreach num of numlist 81/86 {

**Set to zero if don't have that crop
replace c_m440_`num'=0 if (m435==1 & m437_`num'==.)
**Set to zero if shouldn't have answered and did 
replace c_m440_`num'=0 if c_m440_`num'!=0 & c_m440_`num'!=.  & (m435!=1 | m437_`num'==.)
**Set to missing if should have answered and didn't
replace c_m440_`num'=. if c_m440_`num'==0 & (m435==1 & m437_`num'!=.)

sum c_m440_`num'


}

egen harvest=rowtotal(c_m440*), missing

foreach num of numlist 81/86 {
replace harvest=. if c_m440_`num'==.
}


*Monthly and equally per enterprise member
gen iharvest=0 if harvest!=.
replace iharvest=harvest/12/hh_in_ag if in_ag==1


sum iharvest
sum iharvest if iharvest!=0




***Other Ag income
tab1 m442 m444 m446 m448 m450 m452

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m442 m444 m446 m448 m450 m452 {
gen c_`var'=.
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

*Replace missing if should be non-zero
replace c_m442=. if m441==1 & m442==0

*Replace zero if no income
replace c_m442=0 if m441==2

*Replace missing if should be non-zero
replace c_m444=. if m443==1 & m444==0

*Replace zero if no income
replace c_m444=0 if m443==2

*Replace missing if should be non-zero
replace c_m446=. if m445==1 & m446==0

*Replace zero if no income
replace c_m446=0 if m445==2

*Replace missing if should be non-zero
replace c_m448=. if m447==1 & m448==0

*Replace zero if no income
replace c_m448=0 if m447==2

*Replace missing if should be non-zero
replace c_m450=. if m449==1 & m450==0

*Replace zero if no income
replace c_m450=0 if m449==2

*Replace missing if should be non-zero
replace c_m452=. if m451==1 & m452==0

*Replace zero if no income
replace c_m452=0 if m451==2



egen otherag=rowtotal(c_m442 c_m444 c_m446 c_m448 c_m450 c_m452), missing 

*Already monthly

*Per enterprise member
gen iotherag=0 if otherag!=.
replace iotherag=otherag*in_ag/hh_in_ag if in_ag==1

sum iotherag
sum iotherag if iotherag!=0



***Sales of livestock
*Rule: 75% of livestock sales is income


sum m427*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m427* {
gen c_`var'=.
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}


foreach num of numlist 51/58 {

**Set to zero if don't have or sell that animal
replace c_m427_`num'=0 if (m419==2 | m422_`num'==2 | m425_`num'==2)
**Set to zero if shouldn't have answered and did 
replace c_m427_`num'=0 if c_m427_`num'!=0 & c_m427_`num'!=.  & (m419==2 | m422_`num'==2 | m425_`num'==2)
**Set to missing if should have answered and didn't
replace c_m427_`num'=. if c_m427_`num'==0 & (m419==1 & m422_`num'==1 & m425_`num'==1)

sum c_m427_`num'


}

egen livesales=rowtotal(c_m427*), missing

foreach num of numlist 51/58 {
replace livesales=. if c_m427_`num'==. 
}

*Monthly 75% per 
gen ilivesales=0 if livesales!=.
replace ilivesales=livesales/12*.75*in_ag/hh_in_ag if in_ag==1

sum ilivesales 
sum ilivesales if ilivesales!=0

***Total Individual Ag income

gen itotalag=ihhequiprent+iharvest+iotherag+ilivesales

sum itotalag
sum itotalag if itotalag!=0



******************************************************
*Non-labor income--repeats over housheold members (Q3) 
******************************************************

**Assigned to household head

*** Pensions, social assistance, financial and other ***
*Already monthly

sum m249*

tab1 m249*

foreach var of varlist m249* {
gen c_`var'=.
replace c_`var'=`var' if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=.

}

foreach num of numlist 1/7 {
*Missing if not answered y/n
replace c_m249_`num'=. if m248_`num'==.
*Zero if no
replace c_m249_`num'=0 if m248_`num'==2
*Missing if yes and no value
replace c_m249_`num'=. if m248_`num'==1 & c_m249_`num'==0
}

*Fix implausibly large pensions with highest wage observed
replace c_m249_1=9015 if c_m249_1!=. & c_m249_1>9015

sum *m249* 


*Sum of pensions and social assistance - assign to head
egen ipensionsocialasst = rowtotal(c_m249_1-c_m249_4) if pn==1, missing
replace ipensionsocialasst=0 if pn!=1
foreach num of numlist 1/4 {
replace ipensionsocialasst=. if c_m249_`num'==.
}

*Add in other pension but exclude rent and interest
replace ipensionsocialasst = ipensionsocialasst + c_m249_7 if pn==1
replace ipensionsocialasst=. if c_m249_7==.

sum ipensionsocialasst

egen ipension = rowtotal(c_m249_1) if pn==1, missing

foreach num of numlist 1 {
replace ipension=. if c_m249_`num'==.
}

egen isocasst2 = rowtotal(c_m249_2-c_m249_4 c_m249_7) if pn==1, missing

foreach num of numlist 2 3 4 7 {
replace isocasst2=. if c_m249_`num'==.
}

sum ipension isocasst2

*Sum of rent and interest
gen irentother=c_m249_5 + c_m249_6 if pn==1
replace irentother = 0 if irentother==. & c_m249_5!=. & c_m249_6!=. & pn!=1
sum irentother



**********************************
*Remittances, child support, etc.
**********************************

*Assigned to anyone in particular?

tab1 m243*

*Usually. Otherwise will assign to adults 15+ 

foreach num of numlist 1/5 {
gen rec_`num'=0
replace rec_`num'=1 if m244_2`num'==pn
replace rec_`num'=1 if m243_2`num'==2 & age>=15
replace rec_`num'=1 if m243_2`num'==1 & m244_2`num'==. & age>=15
replace rec_`num'=1 if m243_2`num'==. & m238_2`num'!=. & age>=15
replace rec_`num'=1 if hhid=="00130561" & age>=15
egen hh_rec_`num'=sum(rec_`num'), by(hhid)
}


*Annual

sum m246* m247*
tab1 m246* m247*

*Creating a "clean" version with zeroes and cleaning out missings. 
foreach var of varlist m246* m247* {
*Zero if receive none
gen c_`var'=0 if m234==2
replace c_`var'=`var'/12 if `var'!=98 & `var'!=998 & `var'!=9998 & `var'!=99998 & `var'!=999998  & `var'!=999999 & `var'!=.

}


foreach num of numlist 21/25 {


**Set to zero if don't have that donor
replace c_m246_`num'=0 if m235<`num'-20

**Set to missing if should have answered and didn't
replace c_m246_`num'=. if c_m247_`num'==0 & c_m246_`num'==0 & m235>=`num'-20 & m234==1

sum c_m246_`num'


**Set to zero if don't have that donor
replace c_m247_`num'=0 if m235<`num'-20

**Set to missing if should have answered and didn't
replace c_m247_`num'=. if c_m247_`num'==0 & c_m246_`num'==0 & m235>=`num'-20 & m234==1

sum c_m247_`num'


}


foreach num of numlist 1/5 {
gen i_c_m246_2`num'=rec_`num'/hh_rec_`num'*c_m246_2`num'
gen i_c_m247_2`num'=rec_`num'/hh_rec_`num'*c_m247_2`num'
}

egen iremitetc=rowtotal(i_c_m246* i_c_m247*)


foreach num of numlist 21/25 {
replace iremitetc=. if c_m247_`num'==. | c_m246_`num'==.
}

sum iremitetc
sum iremitetc if iremitetc!=0, detail



*** Define Transfers ****
gen itransfers=ipensionsocialasst +iremitetc

sum itransfers
sum itransfers if itransfers!=0

** Total nonlabor income ***
gen inonlaborincome = itransfers + irentother

sum inonlaborincome
sum inonlaborincome if inonlaborincome!=0

********************************
*Total income--before transfers
********************************

gen ipreinc=iwg+ient_earn+itotalag + irentother

sum ipreinc, detail


********************************
*Total income--after transfers
********************************

gen ipostinc = ipreinc + itransfers

sum ipostinc, detail

label variable ipreinc "Pre-transfer individual total monthly income"

label variable ipostinc "Post-transfer individual total monthly income"


****************
*Dataset
****************

*save "EG TN Full Income/Data and do files/TLMPS 2014 full indiv inc.dta", replace
save "TLMPS 2014 full indiv inc.dta", replace

*use "EG TN Full Income/Data and do files/TLMPS 2014 full HH inc.dta", clear
use "TLMPS 2014 full HH inc.dta", clear

merge 1:1 indid using "TLMPS 2014 full indiv inc.dta"
tabu _merge
drop _merge


***PPP terms, 2012
*Rename ppp variables

foreach var of varlist hhwg preinc pcpreinc pcpostinc pchhwg iwg ipreinc ipostinc {
gen pp_`var'=(`var'/(167.1/148.9))/0.79
}

drop c_* i_c* rec_* hh_rec* ag_hrs hh_ag_elig ag_elig hh_in_ag in_ag

*save "EG TN Full Income/Data and do files/TLMPS 2014 full inc.dta", replace
save "TLMPS 2014 full inc.dta", replace


****************
*Checks
****************

sum hhwg iwg ient_earn netearnHH *hhequiprent *harvest *otherag *livesales *totalag ///
*pensionsocialasst *rentother *remitetc *transfers *nonlaborincome *preinc *postinc

sum hhwg iwg ient_earn netearnHH *hhequiprent *harvest *otherag *livesales *totalag ///
*pensionsocialasst *rentother *remitetc *transfers *nonlaborincome *preinc *postinc if pn==1



*Wages 

table sex [fw=round(expan_indiv)], c(sum iwg) format(%15.0f) row col 

table sex [fw=round(expan_indiv)] if reltohd==1, c(sum hhwg) format(%15.0f) row col 

*Pre-transfer

table sex [fw=round(expan_indiv)], c(sum ipreinc sum pcpreinc) format(%15.0f) row col 

table sex [fw=round(expan_indiv)] if reltohd==1, c(sum preinc) format(%15.0f) row col 

*Post-transfer

table sex [fw=round(expan_indiv)], c(sum ipreinc sum pcpreinc) format(%15.0f) row col 

table sex [fw=round(expan_indiv)] if reltohd==1, c(sum preinc) format(%15.0f) row col  


* Check that individual add up to household

egen total_preinc=sum(ipreinc), by(hhid) missing
egen total_postinc=sum(ipostinc), by(hhid) missing
egen total_aginc=sum(itotalag), by(hhid) missing
egen total_wages=sum(iwg), by(hhid) missing
egen total_transfers=sum(itransfers), by(hhid) missing
egen total_remit=sum(iremitetc), by(hhid) missing
egen total_entearn=sum(ient_earn), by(hhid) missing

gen check_preinc = preinc-total_preinc
gen check_postinc = postinc-total_postinc
gen check_wages = hhwg-total_wages
gen check_transfers = transfers-total_transfers
gen check_entearn = netearnHH - total_entearn
gen check_remit = remitetc-total_remit

sum preinc total_preinc postinc total_postinc hhwg total_wages totalag total_aginc transfers total_transfers remitetc total_remit netearnHH total_entearn

sum check*
sum check*, detail



foreach var of varlist check* {
tab1 `var' if `var'!=0
}

*browse  checkwgtot pn hhid preinc total_preinc postinc total_postinc hhwg total_wages totalag ///
total_aginc transfers total_transfers remitetc total_remit netearnHH total_entearn if checkwgtot < -1


/*NO remaining problems with sum of individual income components differing from household for households with sufficient data

count if (check_preinc >1 | check_preinc <-1) & check_preinc!=.

list hhid pn check_transfers pensionsocialasst ipensionsocialasst remitetc iremitetc if check_transfers>1
list hhid pn preinc total_preinc postinc total_postinc hhwg total_wages totalag total_ag remitetc total_remit transfers total_transfers  if check_preinc >10 & check_preinc!=.
list hhid pn preinc total_preinc ipreinc remitetc iremitetc ient_earn if check_preinc >10 & preinc!=.
list hhid pn ient_earn in_ent* ent_hrs n_ent if check_preinc >100 & preinc!=. & ipreinc==. 
list hhid pn preinc total_preinc iremitetc remitetc ient_earn netearnHH if check_preinc >1 | check_preinc <-1
list hhid pn preinc total_preinc ipreinc total_remit remitetc iremitetc ient_earn total_entearn netearnHH if hhid=="00650031" | hhid=="00720101"
list hhid pn irem rem m243* m244* if check_remit>1 | check_remit<-1
*/


drop check*
drop total_*

**Shorten some variable names
rename pensionsocialasst pensocasst
rename ipensionsocialasst ipensocasst
rename nonlaborincome nonlaborinc
rename inonlaborincome inonlaborinc

*Harominze some of the data
tostring psu, replace
replace psu="14"+psu

save "TLMPS 2014 full inc.dta", replace

