*******Full income paper analysis for EGYPT and TUNISIA
*******Name of program: Full income analysis E12 T14 combo v2.do
*******Version 5.0
*******Full income analysis
*******Combining Egypt and Tunisia
*******Caroline Krafft
*******Updated 8/7/19 by CK

** Stata 14.2
version 14.2
set more off


*Data set includes shares of income by type and all individuals not missing postinc
use "ELMPS 2012 full inc HH shares ALL.dta", clear

replace round="2012"
destring round, replace

append using "TLMPS 2014 full inc HH shares ALL.dta"

save "E12 T14 full inc combo.dta", replace


************
*Lorenz
************

**********
*Figure 1: Lorenz curves of income inequality by country
**********

*total income

 glcurve pcpostinc if round==2012 [aw=expan], gl(gleg) p(peg) lorenz replace nograph
 glcurve pcpostinc if round==2014 [aw=expan], gl(gltn) p(ptn) lorenz replace nograph
 
 
 twoway line gleg peg, sort lcolor(orange) lwidth(thick) lpatt(l)  ||  ///
 line gltn ptn, sort lcolor(navy) lwidth(thick) lpatt(dash) || ///
 line gleg gleg , lcolor(gs12) lwidth(thick) ///
 xtitle("Share of Population") ytitle("Share of Income") legend(label(1 "Egypt") label (2 "Tunisia") ///
 label(3 "Equality")) plotregion(margin(zero))
 
 graph save "Graphs/lorenz_pcpostinc_combo.gph", replace
 graph export "Graphs/lorenz_pcpostinc_combo.tif", replace
 
 **********************
 *Figure 4: Components
 **********************
 
*Relabel (shorten)
la var nz_pcwg_pub "Pub. wage"
la var nz_pcwg_priv_form "Priv. form. wg."
la var nz_pcwg_priv_inform "Priv. inform. wg."
la var nz_pcentearn "Ent. earnings"
la var nz_pctotalag "Agric. earnings"
la var nz_pcremit "Remitt. etc."
la var nz_pcpension "Pensions"
la var nz_pcsocasst "Social assistance"
la var nz_pcrent "Rent and other"

 
foreach var of varlist nz_pcwg_pub nz_pcwg_priv_form nz_pcwg_priv_inform ///
nz_pcentearn nz_pctotalag nz_pcremit nz_pcpension nz_pcsocasst nz_pcrent {

local lbe: variable label `var'


glcurve `var' if round==2012 [aw=expan], gl(gleg) p(peg) lorenz replace nograph
glcurve `var' if round==2014 [aw=expan], gl(gltn) p(ptn) lorenz replace nograph


 twoway line gleg peg, sort lcolor(orange) lwidth(thick) lpatt(l) ||  ///
 line gltn ptn, sort lcolor(navy) lwidth(thick) lpatt(dash)  || ///
 line gleg gleg , lcolor(gs12) lwidth(thick) ///
 title("`lbe'") ///
 xtitle("Share of Population") ytitle("Share of Income") legend(label(1 "Egypt") label (2 "Tunisia") ///
 label(3 "Equality")) plotregion(margin(zero))
 
 graph save "Graphs/lorz_`var'_combo.gph", replace
 graph export "Graphs/lorz_`var'_combo.tif", replace

}

grc1leg "Graphs/lorz_nz_pcwg_pub_combo" "Graphs/lorz_nz_pcwg_priv_form_combo" ///
"Graphs/lorz_nz_pcwg_priv_inform_combo" "Graphs/lorz_nz_pcentearn_combo" ///
"Graphs/lorz_nz_pctotalag_combo" "Graphs/lorz_nz_pcremit_combo" ///
"Graphs/lorz_nz_pcpension_combo" "Graphs/lorz_nz_pcsocasst_combo" "Graphs/lorz_nz_pcrent_combo" 

graph display, xsize(20) ysize(20)

graph save "Graphs/lorenz9_nz_combo.gph", replace
graph export "Graphs/lorenz9_nz_combo.tif", replace
