*******Full income paper analysis for EGYPT
*******Name of program: Full income analysis ELMPS 2012 v10.do
*******Version 10.0
*******Liz Davis & Caroline Krafft
*******Last Update 8/7/2019 by CK

** Stata 14

/*Analysis for paper:

Who receives different sources (logits)
Receipt and amount by characteristics
Shares of income sources by income groups
Decomposition of inequality by type of income

** Use this order for the nine sources of income
*hhmnthwg_pub hhmnthwg_priv_form hhmnthwg_priv_inform netearnHH totalag  remitetc pension socasst2 rentother
*shr_public_wage shr_priv_form shr_priv_inform shr_entearn shr_agincome shr_remit shr_pension shr_socasst shr_rent
*anypublicwg anyprivformwg anyprivinformwg anyentearn anyaginc anyremit anypension anysocasst anyrent

*/


set more off
capture log close

*Start log
log using "Full income shares analysis ELMPS log 8.7.19", replace text

*Data set includes shares of income by type and all individuals who are not missing postinc 
use "ELMPS 2012 full inc HH shares ALL.dta", clear

************************************************
************** ANALYSIS FOR EGYPT **************
************************************************

************************************************************************

** Stats: Sample sizes 
codebook indid hhid

**Stats: anywage 
tabu anywage [aw=expan]

** Figure 2: Receipt

tabout sex region urban Qpostinc [aw=expan] using "Graphs/EG_Anysource9.xls", replace ///
c(mean anypublicwg mean anyprivformwg mean anyprivinformwg mean anyentearn mean anyaginc mean anyremit ///
mean anypension mean anysocasst mean anyrent) ptotal(single) lines(none) f(3) sum oneway npos(col)


** Figure 3: SHARES by quintile

preserve

expand 2

bysort indid: replace Qpostinc=6 if _n==2

collapse (sum) pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother pcpostinc [aw=expan], by(Qpostinc)

foreach var of varlist pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother pcpostinc {
gen shr_`var'=`var'/pcpostinc
}

keep shr* Qpostinc

export excel using "Graphs/EG Quint post inc shares9.xls", first(var) replace

restore

** Table 2: NUMBER OF SOURCES

tabout Qpostinc [aw= expan] using "Graphs/EG Number of sources2.xls", replace ///
c(mean num_source4 mean num_source9  ) ///
ptotal(single) lines(none) f(3) sum npos(col)

********************************
*** Table 3: Logits with marginal effects
********************************

 
*** With parental characteristics
 
foreach var of varlist anypublicwg anyprivformwg anyprivinformwg ///
anyentearn anyaginc anyremit anypension anysocasst anyrent {
logit `var' i.sex i.region i.agegrp3 i.marital_status ib3.educ_status6  i.mteducst4 i.fteducst4 i.ftempst2 [pw=expan]

estimates store EG3_`var'

margins, dydx(*) post noestimcheck

estimates store marg_EG3_`var'
}


 
 esttab marg_EG3_* using "Graphs/EG_LogitMarg9b.csv", replace cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g)) label refcat( 2.sex "Sex (male omit.)" ///
 2.region "Region (Gr. Cairo omit.)" ///
 1.agegrp3 "Age (under 15 omit.)" ///
 2.marital_status "Marital status (single omit.)" ///
 0.educ_status6 "Education (basic omit.)" ///
 2.mteducst4 "Mother's education (illit. omit.)" ///
 2.fteducst4 "Father's education (illit. omit.)" ///
 2.ftempst2 "Father's employment (wage worker omit.)" ///
 , nolabel) nobase legend  mlabel("anypublicwg" "anyprivformwg" "anyprivinformwg" /// 
 "anyentearn" "anyaginc" "anyremit" "anypension" "anysocasst" "anyrent" )
 

 
*************************
*Table 1: Inequality Measurement
*************************

ineqdeco pcpostinc [aw=expan] 

matrix define EGineq=r(p90p10) \ r(p75p25) \ r(ge0) \ r(ge1) \ r(ge2) \ r(gini) 

estout matrix(EGineq) using "Graphs/EGineq.xls" , replace

matrix define EG_comp_ineq= EGineq

***Stats with Table 5

foreach var of varlist nz_pcwg_pub nz_pcwg_priv_form nz_pcwg_priv_inform nz_pcentearn ///
nz_pctotalag nz_pcremit nz_pcpension nz_pcsocasst nz_pcrent {
 
ineqdeco `var' [aw=expan] 
 
matrix define EGineq_`var'=r(p90p10) \ r(p75p25) \ r(ge0) \ r(ge1) \ r(ge2) \ r(gini) 

matrix define EGineq = EGineq , EGineq_`var'

}

matrix rownames EGineq = "p90/p10" "p75/p25" "GE(0)" "GE(1)" "GE(2)" "Gini" 
matrix colnames EGineq = "Total income"	"Public wages"	"Private wages"	"Informal wages"	"Enterprise inc."	"Agric. inc."	"Remittances"	"Pensions"	"Social assist."	"Rent & other"
 
estout matrix(EGineq) using "Graphs/EGineq_comp.xls" , replace
 
 
*************************
*Table 5: Inequality Decomposition
*************************

*Correlations
correlate pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother pcpostinc [aw=expan]

matrix define temp=r(C)

estout matrix(temp) using "Graphs/EG correl.xls", replace


*Inequality decomposition
ineqfac pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother [aw=expan] , stats total(check_total3)

*** Output the results of ineqfac for per capita income by source

foreach var of varlist pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother {

gen sc_share_`var'=r(share_`var')
gen sc_cv_`var'=r(cv_`var')
gen sc_sf_`var'=r(sf_`var')

}

destring sc_*, replace

preserve 

collapse sc_* 

export excel using "Graphs/EG_ineqfac_stuff.xls", replace firstrow(var)

restore

****************************************
*Coefficient of variation and mean
****************************************
tabstat  pcpostinc nz_pcwg_pub nz_pcwg_priv_form nz_pcwg_priv_inform nz_pcentearn ///
         nz_pctotalag nz_pcremit nz_pcpension nz_pcsocasst nz_pcrent [aw=expan] , ///
		 stat(mean cv) long col(stat) save
		 
matrix define EG_mean_CV= r(StatTotal)

estout matrix(EG_mean_CV) using "Graphs/EG_mean_CV.xls", replace		 


**END OF PROGRAM

log close
