*******Full income paper analysis for TUNISIA
*******Name of program: Full income analysis TLMPS 2014 v11.do
*******Version 9.0
*******Liz Davis & Caroline Krafft
*******Last Update 8/7/2019 by CK

** Stata 14

/*Analysis for paper:

Who receives different sources (logits)
Receipt and amount by characteristics
Shares of income sources by income groups
Decomposition of inequality by type of income

** Use this order for the nine sources of income
*hhmnthwg_pub hhmnthwg_priv_form hhmnthwg_priv_inform netearnHH totalag  remitetc pension socasst2 rentother
*shr_public_wage shr_priv_form shr_priv_inform shr_entearn shr_agincome shr_remit shr_pension shr_socasst shr_rent
*anypublicwg anyprivformwg anyprivinformwg anyentearn anyaginc anyremit anypension anysocasst anyrent

*/


set more off
capture log close

*Start log
log using "Full income shares analysis TLMPS 8.7.19", replace text

*Data set includes shares of income by type and all individuals not missing postinc
use "TLMPS 2014 full inc HH shares ALL.dta", clear

************************************************
************** ANALYSIS FOR TUNISIA **************
************************************************

************************************************************************


** Stats: Sample sizes 
codebook indid hhid

**Stats: anywage 
tabu anywage [aw=expan]

** Figure 2: Receipt

tabout sex region urban Qpostinc [aw=expan] using "Graphs/Tunisia/Anysource9.xls", replace ///
c(mean anypublicwg mean anyprivformwg mean anyprivinformwg mean anyentearn mean anyaginc mean anyremit ///
mean anypension mean anysocasst mean anyrent) ptotal(single) lines(none) f(3) sum oneway npos(col)




** Figure 3: SHARES by quintile

preserve

expand 2

bysort indid: replace Qpostinc=6 if _n==2

collapse (sum) pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother pcpostinc [aw=expan], by(Qpostinc)

foreach var of varlist pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother pcpostinc {
gen shr_`var'=`var'/pcpostinc
}

keep shr* Qpostinc

export excel using "Graphs/Tunisia/Quint post inc shares9.xls", first(var) replace

restore


** Table 2: NUMBER OF SOURCES
tabout Qpostinc [aw= expan] using "Graphs/Tunisia/Number of sources2.xls" if postinc !=., replace ///
c(mean num_source4 mean num_source9  ) ///
ptotal(single) lines(none) f(3) sum npos(col)

********************************
*** Table 4: Logits with marginal effects
********************************

 *** With parental characteristics
 
foreach var of varlist anypublicwg anyprivformwg anyprivinformwg ///
anyentearn anyaginc anyremit anypension anysocasst /* anyrent (only 40 N so not modeling) */ {
logit `var' i.sex i.urban i.agegrp3 i.marital_status ib3.educ_status6  i.mteducst4 i.fteducst4 i.ftempst2 [pw=expan]

estimates store TN3_`var'
margins, dydx(*) post

estimates store marg_TN3_`var'
}


 
 esttab marg_TN3_* using "Graphs/Tunisia/LogitMarg9b.csv", replace cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g)) label refcat( 2.sex "Sex (male omit.)" ///
 2.region "Region (Urban omit.)" ///
 1.agegrp3 "Age (Under 15 omit.)" ///
 2.marital_status "Marital status (single omit.)" ///
 0.educ_status6 "Education (basic omit.)" ///
 2.mteducst4 "Mother's education (illit. omit.)" ///
 2.fteducst4 "Father's education (illit. omit.)" ///
 2.ftempst2 "Father's employment (wage worker omit.)" ///
 , nolabel) nobase legend  mlabel("anypublicwg" "anyprivformwg" "anyprivinformwg" /// 
 "anyentearn" "anyaginc" "anyremit" "anypension" "anysocasst" )
 
 **NOTE: Anyrent won't converge with parent characteristics (Sample is too small, N=40 have rent).
 
 
 

*************************
*Table 1: Inequality Measurement
*************************

ineqdeco pcpostinc [aw=expan] 

matrix define TNineq=r(p90p10) \ r(p75p25) \ r(ge0) \ r(ge1) \ r(ge2) \ r(gini) 

estout matrix(TNineq) using "Graphs/Tunisia/TNineq.xls" , replace

matrix define TN_comp_ineq= TNineq

***Stats with Table 5

foreach var of varlist nz_pcwg_pub nz_pcwg_priv_form nz_pcwg_priv_inform nz_pcentearn ///
nz_pctotalag nz_pcremit nz_pcpension nz_pcsocasst nz_pcrent {
 
ineqdeco `var' [aw=expan] 
 
matrix define TNineq_`var'=r(p90p10) \ r(p75p25) \ r(ge0) \ r(ge1) \ r(ge2) \ r(gini) 

matrix define TNineq = TNineq , TNineq_`var'

}

matrix rownames TNineq = "p90/p10" "p75/p25" "GE(0)" "GE(1)" "GE(2)" "Gini" 
matrix colnames TNineq = "Total income"	"Public wages"	"Private wages"	"Informal wages"	"Enterprise inc."	"Agric. inc."	"Remittances"	"Pensions"	"Social assist."	"Rent & other"
 
estout matrix(TNineq) using "Graphs/Tunisia/TNineq_comp.xls" , replace


*************************
*Table 5: Inequality Decomposition
*************************

*Correlations
correlate pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother pcpostinc [aw=expan]

matrix define temp=r(C)

estout matrix(temp) using "Graphs/Tunisia/TN correl.xls", replace


ineqfac pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother [aw=expan] , stats total(check_total3)

*** Output the results of ineqfac for per capita income by source

foreach var of varlist pchhmnthwg_pub pchhmnthwg_priv_form pchhmnthwg_priv_inform pcnetearnHH pctotalag ///
pcremitetc pcpension pcsocasst2 pcrentother {

gen sc_share_`var'=r(share_`var')
gen sc_cv_`var'=r(cv_`var')
gen sc_sf_`var'=r(sf_`var')

}

destring sc_*, replace

preserve 

collapse sc_* 

export excel using "Graphs/Tunisia/TN_ineqfac_stuff.xls", replace firstrow(var)

restore

****************************************
*Coefficient of variation and mean
****************************************
tabstat  pcpostinc nz_pcwg_pub nz_pcwg_priv_form nz_pcwg_priv_inform nz_pcentearn ///
         nz_pctotalag nz_pcremit nz_pcpension nz_pcsocasst nz_pcrent [aw=expan], ///
		 stat(mean cv) long col(stat) save
		 
matrix define EG_mean_CV= r(StatTotal)

estout matrix(EG_mean_CV) using "Graphs/Tunisia/TN_mean_CV.xls", replace		
 
 
**END OF PROGRAM

log close
