*******Full income paper analysis data set
*******Name of program: Full income analysis data ELMPS 2012
*******Version 14.0
*******Original 6/16/15
******Last Update 8/7/19 by CK
*******Liz Davis and Caroline Krafft

** Stata 14

/*Creates data set to use for analysis of full income data*/
/* Keeps all individuals, not just household heads*
Creates data set ELMPS 2012 full inc HH shares ALL.dta"*/

capture log close
set more off
 
*Start log
log using "Full income data ELMPS log.log", replace text

************************************************
************** EGYPT ***************************
************************************************
*Use Eygpt data set including both household-level and individual-level income variables
use "ELMPS 2012 full inc.dta", clear


** Create household descriptive variables ***

*Age groups
gen agegrp3=1 if age > 14 & age < 25
replace agegrp3 = 2 if age > 24 & age < 55
replace agegrp3 = 3 if age > 54 & age!=.
replace agegrp3 = 0 if age < 16

tab agegrp3
label define lagegrp3 1 "Age 15-24" 2 "Age 25-54" 3 "Age 55 or older" 0 "Age under 15"
label values agegrp3 lagegrp3
tab agegrp3

*Recode marital status categories
gen marital_status2=.
replace marital_status2=1 if marital==1 | marital==2 | marital==3
replace marital_status2=2 if marital==4 
replace marital_status2=3 if marital==5
replace marital_status2=4 if marital==6

label define mstatus2 1 "single" 2 "married" 3 "divorced/separated" 4 "widowed" 
label values marital_status2 mstatus2

tab marital_status2
tab marital_status2 if age<15

*Recode marital status to match Tunisia categories
gen marital_status=.
replace marital_status=1 if marital==1 | marital==2 | marital==3
replace marital_status=2 if marital==4 
replace marital_status=3 if marital==5 | marital==6


label define mstatus1 1 "single" 2 "married" 3 "widow/div/sep"
label values marital_status mstatus1

tab marital_status
tab marital_status, miss
tab marital_status if age<15, miss

gen married = marital_status==2 & marital_status!=.
tab married

*Educational status for 6+ years old

gen educ_status=1 if educlvl==1 | educlvl==2
replace educ_status=2 if educlvl==3
replace educ_status=3 if educlvl==4
replace educ_status=4 if educlvl==5 
replace educ_status=5 if educlvl==6

label define educ_status  1 "None"  ///
2 "Basic Education" 3 "Intermediate" 4 "Above intermediate" 5 "University & above" 

label variable educ_status  "Education status" 

label values educ_status educ_status

tab educlvl 

tab educ_status
tab educ_status if age > 14 & age <18

drop educ1 educ2

* Creation of dummy variables for educational levels
tab educ_status, gen(educ)
tab educ_status, m

*Change missings for those under age 6
gen educ_status6 = educ_status

replace educ_status6 = 1 if age < 15 & educ_status==1
replace educ_status6 = 2 if age >=15 & educ_status==1
replace educ_status6 = 0 if age < 6
replace educ_status6 = 3 if educ_status==2
replace educ_status6 = 4 if educ_status==3
replace educ_status6 = 5 if educ_status==4 
replace educ_status6 = 6 if educ_status==5 

label define educ_status6  0 "Under age 6" 1 "None (under age 15)"  2 "None (over age 15)" ///
3 "Basic Education" 4 "Secondary" 5 "Above secondary" 6 "University & above" 

label values educ_status6 educ_status6

label variable educ_status6  "Education status" 

tab educ_status6
tab educ_status6, m

tab educ_status6 if age < 12

tab educ_status educ_status6


**Recategorize father's education and employment and mother's education
tab1 fteducst mteducst ftempst, miss
tab1 fteducst mteducst ftempst, miss nolabel


gen fteducst4=1 if fteducst==1
replace fteducst4=2 if fteducst==2 
replace fteducst4=3 if fteducst==3
replace fteducst4=4 if fteducst==4 
replace fteducst4=5 if fteducst >=5 & fteducst<=8
replace fteducst4=6 if fteducst==.

tab fteducst fteducst4, miss

gen mteducst4=1 if mteducst==1
replace mteducst4=2 if mteducst==2 
replace mteducst4=3 if mteducst==3
replace mteducst4=4 if mteducst==4 
replace mteducst4=5 if mteducst >=5 & mteducst<=8
replace mteducst4=6 if mteducst==.

tab mteducst mteducst4, miss

label define fteduc_status4   1 "Illiterate" 2 "Read and write"  ///
3 "Basic Education" 4 "Secondary" 5 "Above secondary" 6 "Missing" 

label values fteducst4 fteduc_status4
label values mteducst4 fteduc_status4

label variable fteducst4 "Father's educ" 
label variable mteducst4 "Mother's educ" 

tab1 fteducst4 mteducst4

tab ftempst, miss
tab ftempst, miss nolabel

gen ftempst2 = 1 if ftempst==1
replace ftempst2 = 2 if ftempst==2
replace ftempst2 = 3 if ftempst==3 | ftempst==4
replace ftempst2 = 4 if ftempst==5
replace ftempst2 = 5 if ftempst==.
tab ftempst ftempst2, miss

label define empl_status2   1 "Wage Worker"   2 "Employer" ///
3 "Self-employed/Family" 4 "No job" 5 "Missing" 

label values ftempst2 empl_status2

label variable ftempst2 "Father's employment status (when Resp. 15)" 
tab ftempst2

*Set parents char. to missing if not under 6 and missing
replace ftempst2=. if ftempst2==5 & educ_status6!=0
replace fteducst4=. if fteducst4==6 & educ_status6!=0
replace mteducst4=. if mteducst4==6 & educ_status6!=0

***Save dataset to merge back in after calculating household income
save "ELMPS 2012 full inc indiv TEMP.dta", replace

**************************
***** INCOME SOURCES *****
**************************

*=================================
* HOUSEHOLD LEVEL ANALYSIS
*=================================

*Keep household head data only to create these variables at the household level
drop if pn!=1 

*Create variables for those who had any of each source of income
*Wages (head and others)
gen anywage = hhwg > 0 & hhwg<. if hhwg!=. 

gen anypublicwg = hhmnthwg_pub > 0 & hhmnthwg_pub<. if hhmnthwg_pub!=. 
gen anyprivformwg = hhmnthwg_priv_form > 0 & hhmnthwg_priv_form<. if hhmnthwg_priv_form!=.
gen anyprivinformwg = hhmnthwg_priv_inform > 0 & hhmnthwg_priv_inform<. if hhmnthwg_priv_inform!=.

*HH enterprises
gen anyentearn = netearnHH > 0 & netearnHH<. if netearnHH!=. 
* Agricultural income
gen anyagincome = totalag > 0 & totalag<. if totalag!=. 
gen anylivesales = livesales > 0 & livesales<. if livesales!=. 
gen anycropsales = harvest > 0 & harvest<. if harvest!=.
gen anyotherag = (hhequiprent + otherag)> 0 & (hhequiprent + otherag)<. 

*Pensions, remittances and other sources
gen anypension = pension > 0 & pension <. if pension !=.
gen anysocasst = socasst2 > 0 & socasst2 <. if socasst2 !=.
gen anyremit = remitetc > 0 & remitetc <. if remitetc !=. 
gen anyrent = rentother > 0 & rentother <. if rentother !=. 

*Transfers include pensions, social assistance and remittances etc
gen anytransfers = transfers > 0 & transfers<. if transfers!=. 

*Nonlabor income includes transfers plus rentother (rent, interest, taxi)
gen anynonlaborinc = nonlaborinc > 0 & nonlaborinc<. if nonlaborinc!=. 

tab1 any*

************************************************
***** INCOME SHARES *****
*Share of total household income  post-tranfers *
************************************************
count if preinc == 0 //N=1,762
count if postinc == 0 // N=180 *DROP THESE b/c missing shares
drop if postinc ==0

*Wages (head and others) 
gen shr_public_wage = hhmnthwg_pub / postinc
gen shr_priv_form = hhmnthwg_priv_form / postinc
gen shr_priv_inform = hhmnthwg_priv_inform / postinc

*HH enterprises
gen shr_entearn = netearnHH / postinc

* Agricultural income *totalag=hhequiprent+harvest+otherag+livesales
gen shr_agincome = totalag / postinc
gen shr_livesale = livesales / postinc
gen shr_cropsale = harvest / postinc
gen shr_otherag = (hhequiprent + otherag) / postinc

*Pensions, remittances and other sources
gen shr_pensoc = pensocasst / postinc
gen shr_remit = remitetc / postinc
gen shr_rent = rentother / postinc

gen shr_pension = pension / postinc
gen shr_socasst2 = socasst2/postinc

*Transfers include pensions, social assistance and remittances etc
gen shr_transfer = transfers / postinc

*Nonlabor income includes transfers plus rentother (rent, interest, taxi)
gen shr_nonlabor = nonlaborinc/ postinc

sum shr*

** CHECKS
gen checktotal = shr_public_wage + shr_priv_form + shr_priv_inform + shr_entearn + shr_agincome + shr_rent + shr_transfer 
gen checktransfers = (shr_pensoc + shr_remit) - shr_transfer 
gen checkag = shr_agincome - (shr_livesale + shr_cropsale + shr_otherag)
gen checknonlabor = shr_nonlabor - (shr_rent + shr_transfer)
gen checknewpen = shr_pension + shr_socasst - shr_pensoc

egen totalhhinc = rowtotal(hhmnthwg_pub hhmnthwg_priv_form hhmnthwg_priv_inform netearnHH totalag remitetc pension socasst2 rentother)
gen checktotalinc = totalhhinc - postinc

sum check*


*** Check missings -- shares are missing when total hh income is zero
*browse shr_wage shr_entearn shr_agincome shr_rent shr_transfer totalhhinc postinc pn if checktotal ==.

drop check*

*Add labels
label variable anywage  "Had wages"
label variable anypublicwg  "Had gov. or public wages"
label variable anyprivformwg  "Had formal private wages"
label variable anyprivinformwg  "Had informal private wages"
label variable anyentearn  "Had enterprise income"
label variable anyagincome  "Had farm income"
label variable anylivesales  "Had livestock income"
label variable anycropsales "Had crop income"
label variable anyotherag "Had other ag income"
label variable anyremit  "Had remittances"
label variable anyrent "Had rent or interest income"
label variable anytransfers  "Had transfers"
label variable anynonlaborinc  "Had nonlabor income"
label variable anypension "Had pension income"
label variable anysocasst "Had social asst."

label variable shr_public_wage "Public wages share"
label variable shr_priv_form "Private formal wages share"
label variable shr_priv_inform "Private informal wages"

label variable shr_entearn "HH enterprise share"
label variable shr_agincome "Agricultural share"
label variable shr_livesale "Livestock share"
label variable shr_cropsale "Crops share"
label variable shr_pensoc "Pensions & assist. share"
label variable shr_remit "Remittances share"
label variable shr_rent "Rent/interest share"
label variable shr_transfer "Transfers share"
label variable shr_nonlabor "Nonlabor share"
label variable shr_otherag "Other sources of agric income"
label variable shr_pension "Pension share"
label variable shr_socasst "Social asst. share"

*=============================
*Number of sources
*=============================

gen num_source4 = anywage + anyentearn + anyagincome + anynonlaborinc
gen num_source9 = anypublicwg + anyprivformwg + anyprivinformwg + anyentearn + anyagincome + anyremit + anypension + anysocasst + anyrent

sum num_*
sum num_*, detail
*bys urban: sum num_, detail

*=============================
* Income amounts by source without zeros
*=============================
* hhmnthwg_pub hhmnthwg_priv_form hhmnthwg_priv_inform netearnHH totalag remitetc pension socasst2 rentother

gen nz_wg_pub = hhmnthwg_pub if hhmnthwg_pub > 0
gen nz_wg_priv_form = hhmnthwg_priv_form if hhmnthwg_priv_form > 0
gen nz_wg_priv_inform = hhmnthwg_priv_inform if hhmnthwg_priv_inform > 0
gen nz_entearn = netearnHH if netearnHH > 0
gen nz_totalag = totalag if totalag > 0
gen nz_remit = remitetc if remitetc > 0
gen nz_pension = pension if pension > 0
gen nz_socasst = socasst2 if socasst2 > 0
gen nz_rent = rentother if rentother > 0

**Per capita amounts conditional on receiving any
gen nz_pcwg_pub = pchhmnthwg_pub if pchhmnthwg_pub > 0
gen nz_pcwg_priv_form = pchhmnthwg_priv_form if pchhmnthwg_priv_form > 0
gen nz_pcwg_priv_inform = pchhmnthwg_priv_inform if pchhmnthwg_priv_inform > 0
gen nz_pcentearn = pcnetearnHH if pcnetearnHH > 0
gen nz_pctotalag = pctotalag if pctotalag > 0
gen nz_pcremit = pcremitetc if pcremitetc > 0
gen nz_pcpension = pcpension if pcpension > 0
gen nz_pcsocasst = pcsocasst2 if pcsocasst2 > 0
gen nz_pcrent = pcrentother if pcrentother > 0

sum nz*

label var nz_pcwg_pub "Per cap public wages"
label var nz_pcwg_priv_form  "Per cap private wages"
label var nz_pcwg_priv_inform "Per cap informal wages"
label var nz_pcentearn "Per cap enterprise inc."
label var nz_pctotalag "Per cap agric inc."
label var nz_pcremit "Per cap remittances"
label var nz_pcpension "Per cap pensions"
label var nz_pcsocasst "Per cap socail asst."
label var nz_pcrent "Per cap rent, interest"

sum preinc postinc hhwg hhmnthwg_pub hhmnthwg_priv_form hhmnthwg_priv_inform netearnHH totalag remitetc pension socasst2 rentother

gen nosource = 1 if anywage==. & anyentearn==. & anywage==. &  anyagincome==. &  anynonlaborinc==. 
count if nosource==1
sum preinc postinc hhwg  netearnHH totalag rentother transfers remitetc pensocasst nonlaborinc if nosource==1
*list hhid pn if nosource==1

*******************
*******************
*DATA SET
******************
******************

save "ELMPS 2012 full inc HH shares.dta", replace
*============================================================================


* MERGE BACK IN INDIVIDUAL DATA 

use "ELMPS 2012 full inc indiv TEMP.dta", clear

merge m:1 hhid using "ELMPS 2012 full inc HH shares.dta"
tabu _merge
tabu _merge, nol

drop _merge

save "ELMPS 2012 full inc HH shares ALL.dta", replace

use "ELMPS 2012 full inc HH shares ALL.dta", clear

tab1 anywage educ_status6
tab1 anywage educ_status6 if pn==1

sum postinc, detail

**KEEP ONLY CASES THAT ARE NOT MISSING POSTINC**
keep if postinc !=. & postinc!=0

*==========================
*Income quintiles
*=============================

xtile Qpreinc=preinc [aw=expan], n(5)
xtile Qpostinc=postinc  [aw=expan], n(5)
xtile Qwages=hhwg  [aw=expan], n(5)
xtile Qaginc=totalag [aw=expan], n(5)
xtile Qrentother=rentother [aw=expan], n(5)
xtile Qtransfers=transfers [aw=expan], n(5)
xtile Qremitetc=remitetc [aw=expan], n(5)
xtile Qpensoc=pensocasst [aw=expan], n(5)
xtile Qpension=pension [aw=expan], n(5)
xtile Qsocasst=socasst2 [aw=expan], n(5)
xtile Qnonlbr=nonlaborinc [aw=expan], n(5)

label define Lquint 1 "Poorest" 2 "Poorer" 3 "Middle" 4 "Richer" 5 "Richest"
la val Qpreinc Lquint
la val Qpostinc Lquint
la val Qwages Lquint
la val Qaginc Lquint
la val Qrentother Lquint
la val Qtransfers Lquint
la val Qremitetc Lquint
la val Qpensoc Lquint
la val Qnonlbr Lquint

**SAVE DATA SET **
save "ELMPS 2012 full inc HH shares ALL.dta", replace


log close
